@@ -25,7 +25,6 @@ sampled.  In general the observed units are independent and
 identically distributed.
 """
 
-from __future__ import division
 from statsmodels.tools.decorators import cache_readonly
 import numpy as np
 from scipy import stats
@@ -79,15 +78,15 @@ class Table(object):
 
     Parameters
     ----------
-    table : array-like
+    table : array_like
         A contingency table.
-    shift_zeros : boolean
+    shift_zeros : bool
         If True and any cell count is zero, add 0.5 to all values
         in the table.
 
     Attributes
     ----------
-    table_orig : array-like
+    table_orig : array_like
         The original table is cached as `table_orig`.
 
     See Also
@@ -129,10 +128,10 @@ class Table(object):
 
         Parameters
         ----------
-        data : array-like
+        data : array_like
             The raw data, from which a contingency table is constructed
             using the first two columns.
-        shift_zeros : boolean
+        shift_zeros : bool
             If True and any cell count is zero, add 0.5 to all values
             in the table.
 
@@ -162,7 +161,7 @@ class Table(object):
 
         statistic : float
             The chi^2 test statistic.
-        df : integer
+        df : int
             The degrees of freedom of the reference distribution
         pvalue : float
             The p-value for the test.
@@ -187,9 +186,9 @@ class Table(object):
 
         Parameters
         ----------
-        row_scores : array-like
+        row_scores : array_like
             An array of numeric row scores
-        col_scores : array-like
+        col_scores : array_like
             An array of numeric column scores
 
         Returns
@@ -433,10 +432,10 @@ class SquareTable(Table):
 
     Parameters
     ----------
-    table : array-like
+    table : array_like
         A square contingency table, or DataFrame that is converted
         to a square form.
-    shift_zeros : boolean
+    shift_zeros : bool
         If True and any cell count is zero, add 0.5 to all values
         in the table.
 
@@ -523,7 +522,7 @@ class SquareTable(Table):
 
         Parameters
         ----------
-        method : string
+        method : str
             Either 'stuart_maxwell' or 'bhapkar', leading to two different
             estimates of the covariance matrix for the estimated
             difference between the row margins and the column margins.
@@ -534,7 +533,7 @@ class SquareTable(Table):
             The chi^2 test statistic
         pvalue : float
             The p-value of the test statistic
-        df : integer
+        df : int
             The degrees of freedom of the reference distribution
 
         Notes
@@ -612,9 +611,9 @@ class SquareTable(Table):
         ----------
         alpha : float
             `1 - alpha` is the nominal coverage probability of the interval.
-        float_format : string
+        float_format : str
             Used to format numeric values in the table.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -639,9 +638,9 @@ class Table2x2(SquareTable):
 
     Parameters
     ----------
-    table : array-like
+    table : array_like
         A 2x2 contingency table
-    shift_zeros : boolean
+    shift_zeros : bool
         If true, 0.5 is added to all cells of the table if any cell is
         equal to zero.
 
@@ -675,10 +674,10 @@ class Table2x2(SquareTable):
 
         Parameters
         ----------
-        data : array-like
+        data : array_like
             The raw data, the first column defines the rows and the
             second column defines the columns.
-        shift_zeros : boolean
+        shift_zeros : bool
             If True, and if there are any zeros in the contingency
             table, add 0.5 to all four cells of the table.
         """
@@ -750,7 +749,7 @@ class Table2x2(SquareTable):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             confidence interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -771,7 +770,7 @@ class Table2x2(SquareTable):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             confidence interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -843,7 +842,7 @@ class Table2x2(SquareTable):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             confidence interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -863,7 +862,7 @@ class Table2x2(SquareTable):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             confidence interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -879,9 +878,9 @@ class Table2x2(SquareTable):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the confidence
             intervals.
-        float_format : string
+        float_format : str
             Used to format the numeric values in the table.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -940,8 +939,12 @@ class StratifiedTable(object):
             sp = tables.shape
             if (len(sp) != 3) or (sp[0] != 2) or (sp[1] != 2):
                 raise ValueError("If an ndarray, argument must be 2x2xn")
-            table = tables
+            table = tables * 1.  # use atleast float dtype
         else:
+            if any([np.asarray(x).shape != (2, 2) for x in tables]):
+                m = "If `tables` is a list, all of its elements should be 2x2"
+                raise ValueError(m)
+
             # Create a data cube
             table = np.dstack(tables).astype(np.float64)
 
@@ -987,7 +990,7 @@ class StratifiedTable(object):
         strata : int or string
             The column index or name of `data` specifying the variable
             defining the strata.
-        data : array-like
+        data : array_like
             The raw data.  A cross-table for analysis is constructed
             from the first two columns.
 
@@ -1025,7 +1028,7 @@ class StratifiedTable(object):
 
         Parameters
         ----------
-        correction : boolean
+        correction : bool
             If True, use the continuity correction when calculating the
             test statistic.
 
@@ -1100,9 +1103,9 @@ class StratifiedTable(object):
 
         References
         ----------
-        Robins, James, Norman Breslow, and Sander Greenland. "Estimators of
-            the Mantel-Haenszel Variance Consistent in Both Sparse Data and
-            Large-Strata Limiting Models." Biometrics 42, no. 2 (1986): 311-23.
+        J. Robins, N. Breslow, S. Greenland. "Estimators of the
+        Mantel-Haenszel Variance Consistent in Both Sparse Data and
+        Large-Strata Limiting Models." Biometrics 42, no. 2 (1986): 311-23.
         """
 
         adns = np.sum(self._ad / self._n)
@@ -1128,7 +1131,7 @@ class StratifiedTable(object):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
 
@@ -1159,7 +1162,7 @@ class StratifiedTable(object):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             interval.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
 
@@ -1184,7 +1187,7 @@ class StratifiedTable(object):
 
         Parameters
         ----------
-        adjust : boolean
+        adjust : bool
             Use the 'Tarone' adjustment to achieve the chi^2
             asymptotic distribution.
 
@@ -1206,7 +1209,8 @@ class StratifiedTable(object):
         c = -r * self._apb * self._apc
 
         # Expected value of first cell
-        e11 = (-b + np.sqrt(b**2 - 4*a*c)) / (2*a)
+        dr = np.sqrt(b**2 - 4*a*c)
+        e11 = (-b + dr) / (2*a)
 
         # Variance of the first cell
         v11 = (1 / e11 + 1 / (self._apc - e11) + 1 / (self._apb - e11) +
@@ -1238,9 +1242,9 @@ class StratifiedTable(object):
         alpha : float
             `1 - alpha` is the nominal coverage probability of the
             confidence intervals.
-        float_format : string
+        float_format : str
             Used for formatting numeric values in the summary.
-        method : string
+        method : str
             The method for producing the confidence interval.  Currently
             must be 'normal' which uses the normal approximation.
         """
@@ -1292,7 +1296,7 @@ def mcnemar(table, exact=True, correction=True):
 
     Parameters
     ----------
-    table : array-like
+    table : array_like
         A square contingency table.
     exact : bool
         If exact is true, then the binomial distribution will be used.
@@ -1329,7 +1333,13 @@ def mcnemar(table, exact=True, correction=True):
     if exact:
         statistic = np.minimum(n1, n2)
         # binom is symmetric with p=0.5
-        pvalue = stats.binom.cdf(statistic, n1 + n2, 0.5) * 2
+        # SciPy 1.7+ requires int arguments
+        int_sum = int(n1 + n2)
+        if int_sum != (n1 + n2):
+            warnings.warn("exact can only be used with tables containing "
+                          "integers. This warning will become a ValueError "
+                          "after 0.12.", FutureWarning)
+        pvalue = stats.binom.cdf(statistic, int_sum, 0.5) * 2
         pvalue = np.minimum(pvalue, 1)  # limit to 1 if n1==n2
     else:
         corr = int(correction)  # convert bool to 0 or 1
@@ -1351,7 +1361,7 @@ def cochrans_q(x, return_object=True):
     ----------
     x : array_like, 2d (N, k)
         data with N cases and k variables
-    return_object : boolean
+    return_object : bool
         Return values as bunch instead of as individual values.
 
     Returns
@@ -1383,7 +1393,7 @@ def cochrans_q(x, return_object=True):
 
     References
     ----------
-    http://en.wikipedia.org/wiki/Cochran_test
+    https://en.wikipedia.org/wiki/Cochran_test
     SAS Manual for NPAR TESTS
     """
 
